ConversionError

Enum ConversionError 

pub enum ConversionError {
    HoleNotSupported,
    HoleInLiteral,
    NonStringMapKeysNotSupported,
    BigIntOutOfRange(String),
    InvalidFloatValue(String),
    InvalidNodeReference(usize),
    CircularReference(String),
    JsonConversion(EureToJsonError),
    InvalidDefaultValue {
        expected: &'static str,
        actual: String,
    },
}
Errors that can occur during Eure Schema to JSON Schema conversion

Variants



HoleNotSupported

Eure Hole type cannot be represented in JSON Schema



HoleInLiteral

Eure Hole in literal value cannot be represented in JSON Schema



NonStringMapKeysNotSupported

Eure Map type with non-string keys cannot be represented in JSON Schema



BigIntOutOfRange(String)

BigInt value is too large to fit in i64 for JSON Schema



InvalidFloatValue(String)

Float value (NaN or Infinity) cannot be represented in JSON Schema



InvalidNodeReference(usize)

Invalid schema node reference



CircularReference(String)

Circular reference detected (not supported in JSON Schema)



JsonConversion(EureToJsonError)

JSON conversion error (from eure-json)



InvalidDefaultValue

Invalid default value type

Fields

expected: &'static str
actual: String